use std::borrow::Borrow;
use teloxide::{adaptors::Throttle, prelude::*};

/// Deletes the message ignoring the errors
#[inline]
pub async fn delete_message(bot: Throttle<Bot>, msg: Message) {
    let _ = bot.delete_message(msg.chat.id, msg.id).await;
}

/// Deletes the message if there is one ignoring the errors
#[inline]
pub async fn delete_optional(bot: &Throttle<Bot>, msg: Option<impl Borrow<Message>>) {
    if let Some(msg) = msg {
        let msg: &Message = msg.borrow();
        let _ = bot.delete_message(msg.chat.id, msg.id).await;
    }
}

/// Returns true if the field is valid
#[inline]
pub fn validate_field(field: &str) -> bool {
    field
        .chars()
        .all(|char| char != '`' && char != '\\' && char != '\n')
}
